aboutsummaryrefslogtreecommitdiffstats
path: root/tools/libxen
diff options
context:
space:
mode:
authorEwan Mellor <ewan@xensource.com>2007-02-20 19:23:28 +0000
committerEwan Mellor <ewan@xensource.com>2007-02-20 19:23:28 +0000
commitcdbec983afc81c50a0262970cae4b01fee651357 (patch)
treea867f1953ec406f9da3ca889a3f5d3a1b0c0cadf /tools/libxen
parentada588411f0ee53081fa6054e073089a4aa6cc4f (diff)
downloadxen-cdbec983afc81c50a0262970cae4b01fee651357.tar.gz
xen-cdbec983afc81c50a0262970cae4b01fee651357.tar.bz2
xen-cdbec983afc81c50a0262970cae4b01fee651357.zip
Rename Console.uri to location. Xend already uses the latter.
Signed-off-by: Ewan Mellor <ewan@xensource.com>
Diffstat (limited to 'tools/libxen')
-rw-r--r--tools/libxen/include/xen_console.h12
-rw-r--r--tools/libxen/src/xen_console.c12
2 files changed, 12 insertions, 12 deletions
diff --git a/tools/libxen/src/xen_console.c b/tools/libxen/src/xen_console.c
index 18ae6ee498..ea014db03e 100644
--- a/tools/libxen/src/xen_console.c
+++ b/tools/libxen/src/xen_console.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2006, XenSource Inc.
+ * Copyright (c) 2006-2007, XenSource Inc.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -44,9 +44,9 @@ static const struct_member xen_console_record_struct_members[] =
{ .key = "protocol",
.type = &xen_console_protocol_abstract_type_,
.offset = offsetof(xen_console_record, protocol) },
- { .key = "uri",
+ { .key = "location",
.type = &abstract_type_string,
- .offset = offsetof(xen_console_record, uri) },
+ .offset = offsetof(xen_console_record, location) },
{ .key = "VM",
.type = &abstract_type_ref,
.offset = offsetof(xen_console_record, vm) }
@@ -71,7 +71,7 @@ xen_console_record_free(xen_console_record *record)
}
free(record->handle);
free(record->uuid);
- free(record->uri);
+ free(record->location);
xen_vm_record_opt_free(record->vm);
free(record);
}
@@ -164,7 +164,7 @@ xen_console_get_protocol(xen_session *session, enum xen_console_protocol *result
bool
-xen_console_get_uri(xen_session *session, char **result, xen_console console)
+xen_console_get_location(xen_session *session, char **result, xen_console console)
{
abstract_value param_values[] =
{
@@ -175,7 +175,7 @@ xen_console_get_uri(xen_session *session, char **result, xen_console console)
abstract_type result_type = abstract_type_string;
*result = NULL;
- XEN_CALL_("console.get_uri");
+ XEN_CALL_("console.get_location");
return session->ok;
}
diff --git a/tools/libxen/include/xen_console.h b/tools/libxen/include/xen_console.h
index d8c8f508df..778cbbb4e1 100644
--- a/tools/libxen/include/xen_console.h
+++ b/tools/libxen/include/xen_console.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2006, XenSource Inc.
+ * Copyright (c) 2006-2007, XenSource Inc.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -26,8 +26,8 @@
/*
- * The console class.
- *
+ * The console class.
+ *
* A console.
*/
@@ -65,7 +65,7 @@ typedef struct xen_console_record
xen_console handle;
char *uuid;
enum xen_console_protocol protocol;
- char *uri;
+ char *location;
struct xen_vm_record_opt *vm;
} xen_console_record;
@@ -191,10 +191,10 @@ xen_console_get_protocol(xen_session *session, enum xen_console_protocol *result
/**
* Get the uri field of the given console.
*/
extern bool
-xen_console_get_uri(xen_session *session, char **result, xen_console console);
+xen_console_get_location(xen_session *session, char **result, xen_console console);
/**
@@ -191,10 +191,10 @@ xen_console_get_protocol(xen_session *session, enum xen_console_protocol *result
/**
- * Get the uri field of the given console.
+ * Get the location field of the given console.
*/
extern bool